﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.IO;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace Kivii.Pdf.Test
{
    public partial class frmMain : Form
    {
        public frmMain()
        {
            InitializeComponent();
        }

        private void btnSelectFile_Click(object sender, EventArgs e)
        {
            OpenFileDialog ofd = new OpenFileDialog();
            ofd.Filter = "Pdf文件|*.pdf";
            if (ofd.ShowDialog() != DialogResult.OK) return;
            tbxPdfFilePath.Text = ofd.FileName;
            tbxSaveFolder.Text = System.IO.Path.GetDirectoryName(ofd.FileName);
        }

        private void btnSelectStamp_Click(object sender, EventArgs e)
        {
            OpenFileDialog ofd = new OpenFileDialog();
            ofd.Filter = "图片|*.png;*.jpg;*.gif";
            if (ofd.ShowDialog() != DialogResult.OK) return;
            tbxStampFilePath.Text = ofd.FileName;

        }

        private void btnSelectPfx_Click(object sender, EventArgs e)
        {
            OpenFileDialog ofd = new OpenFileDialog();
            ofd.Filter = "数字证书|*.pfx";
            if (ofd.ShowDialog() != DialogResult.OK) return;
            tbxSignatureFilePath.Text = ofd.FileName;
        }

        private void btnSelectSaveFolder_Click(object sender, EventArgs e)
        {
            FolderBrowserDialog sfd = new FolderBrowserDialog();
            if (sfd.ShowDialog() != DialogResult.OK) return;
            tbxSaveFolder.Text = sfd.SelectedPath;

        }

        private StampSetting getSetting()
        {
            try
            {
                var rtns = new StampSetting();
                rtns.StampFilePath = tbxStampFilePath.Text;
                rtns.StampWidth = tbxStampWidth.Text;
                rtns.Pages = tbxPages.Text;
                rtns.OffsetX = tbxOffsetX.Text;
                rtns.OffsetY = tbxOffsetY.Text;
                rtns.MatchText = tbxMatchText.Text;
                rtns.SignatureFilePath = tbxSignatureFilePath.Text;
                rtns.SignatureFilePassword = tbxSignatureFilePassword.Text;
                rtns.SignatureReason = tbxSignatureReason.Text;
                rtns.SignatureLocation = tbxSignatureLocation.Text;
                rtns.SignatureTimeStampAuthorityUrl = tbxSignatureTimeStampAuthorityUrl.Text;

                rtns.StampType = (StampType)Enum.Parse(typeof(StampType), cbxStampType.Text.Split('-')[0]);
                return rtns;
            }
            catch
            {
                return null;
            }

        }
        private void btnStamp_Click(object sender, EventArgs e)
        {
            var setting = getSetting();
            if (setting == null)
            {
                MessageBox.Show("参数设置有误");
                return;
            }
            PdfReader reader = null;
            try
            {
                if (tbxPdfFilePath.Text.StartsWith("http", StringComparison.CurrentCultureIgnoreCase))
                {
                    reader = new PdfReader(new Uri(tbxPdfFilePath.Text));
                }
                else
                {
                    reader = new PdfReader(tbxPdfFilePath.Text);
                }

                var saveFilePath = System.IO.Path.Combine(tbxSaveFolder.Text, System.IO.Path.GetFileNameWithoutExtension(tbxPdfFilePath.Text) + "_" + setting.StampType.ToString() + ".pdf");
                if (System.IO.File.Exists(saveFilePath)) System.IO.File.Delete(saveFilePath);
                var result = reader.Stamp(setting, saveFilePath);
                MessageBox.Show($"操作结果:{result}");
            }
            catch (Exception ex)
            {
                MessageBox.Show($"发生错误:{ex.Message}");
            }
            finally
            {
                reader?.Close();
            }
        }
        private void btnSelectFile2_Click(object sender, EventArgs e)
        {
            OpenFileDialog ofd = new OpenFileDialog();
            ofd.Filter = "Pdf文件|*.pdf";
            if (ofd.ShowDialog() != DialogResult.OK) return;
            tbxPdfFilePath2.Text = ofd.FileName;
            tbxSaveFolder2.Text = System.IO.Path.GetDirectoryName(ofd.FileName);

        }

        private void btnSelectSaveFolder2_Click(object sender, EventArgs e)
        {
            FolderBrowserDialog sfd = new FolderBrowserDialog();
            if (sfd.ShowDialog() != DialogResult.OK) return;
            tbxSaveFolder2.Text = sfd.SelectedPath;

        }
        private void btnStamp2_Click(object sender, EventArgs e)
        {
            var folder = AppDomain.CurrentDomain.BaseDirectory;

            List<StampSetting> settings = new List<StampSetting>();
            var setting = new StampSetting();
            #region 替换QRCODE
            setting.Pages = "1";
            setting.MatchText = "W139,H141";
            setting.StampType = StampType.Replace;
            setting.StampFilePath = Path.Combine(folder, "qrcode.png");
            settings.Add(setting);
            #endregion

            #region 移除签章
            setting = new StampSetting();
            setting.Pages = "1";
            setting.MatchText = "W240,H240";
            setting.StampType = StampType.Replace;
            setting.StampFilePath = string.Empty;
            settings.Add(setting);
            #endregion

            #region 加骑缝章
            setting = new StampSetting();
            setting.Pages = "1-E";
            setting.StampType = StampType.Paging;
            setting.StampFilePath = Path.Combine(folder, "stamp.png");
            settings.Add(setting);
            #endregion

            #region 加水印
            setting = new StampSetting();
            setting.Pages = "1-E";
            setting.StampType = StampType.WaterMark;
            setting.StampFilePath = Path.Combine(folder, "watermark.png");
            settings.Add(setting);
            #endregion

            #region 数字签名
            setting = new StampSetting();
            setting.Pages = "1";
            setting.MatchText = "*签发日期*";
            setting.StampType = StampType.Signature;
            setting.StampFilePath = Path.Combine(folder, "stamp.png");
            setting.SignatureFilePath= Path.Combine(folder, "st_leo.pfx");
            setting.SignatureFilePassword = "www.kivii.com";
            setting.SignatureReason = "Test";
            setting.SignatureLocation = "Nanjing";
            settings.Add(setting);
            #endregion

            var normalSettings = settings.Where(o => o.StampType != StampType.Signature);
            var reader = new PdfReader(tbxPdfFilePath2.Text);
            //var stamper=new PdfStamper(reader,)
        }


    }
}
